@@ -565,6 +565,9 @@ pub static FUNC_RENAME: Lazy<HashMap<&str, &str>> = Lazy::new(|| hashmap! {
 });
 
 pub static FUNC_CFG_ATTR: Lazy<HashMap<&str, (&str, &str)>> = Lazy::new(|| hashmap! {
+	// ### core ###
+	"cv_SparseMatConstIterator_operatorSS" => ("not(target_os = \"windows\")", "!defined(OCVRS_TARGET_OS_WINDOWS)"),
+
 	// ### imgproc ###
 	"cv_getRotationMatrix2D__Point2f_double_double" => ("not(target_os = \"windows\")", "!defined(OCVRS_TARGET_OS_WINDOWS)"),
 
@@ -676,6 +679,7 @@ pub static ELEMENT_EXPORT_MANUAL: Lazy<HashMap<&str, ExportConfig>> = Lazy::new(
 	"cv::ocl::Device" => ExportConfig::default(),
 });
 
+#[allow(clippy::type_complexity)]
 pub static ELEMENT_EXPORT_TWEAK: Lazy<HashMap<&str, fn (&mut ExportConfig)>> = Lazy::new(|| hashmap! {
 	"cv::dnn::ClassificationModel" => ExportConfig::make_boxed as _,
 	"cv::dnn::DetectionModel" => ExportConfig::make_boxed as _,
@@ -1092,6 +1096,8 @@ pub static GENERATOR_MODULE_TWEAKS: Lazy<HashMap<&str, ModuleTweak>> = Lazy::new
 			"std::vector<std::vector<cv::Point3d>>",
 			"std::vector<cv::Vec3f>",
 			"std::vector<std::vector<cv::Vec3f>>",
+			// for solve_pnp tvec and rvec parameters
+			"std::vector<std::vector<double>>",
 		],
 		..Default::default()
 	},
