@@ -1,13 +1,13 @@
 {{attributes_begin}}
 {{debug}}
-{{return_wrapper_type}} {{identifier}}({{decl_args}}) {
-	try {
+{{return_spec}} {{identifier}}({{decl_args}}) {
+	{{try}}
 		{{pre_call_args}}
 		{{call}}
 		{{post_call_args}}
 		{{cleanup_args}}
 		{{return}}
-	} OCVRS_CATCH(OCVRS_TYPE({{return_wrapper_type}}))
+	{{catch}}
 }
 {{attributes_end}}
 
